Welcome to SystemAIR-API's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   api
   modules/index
   contributing
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`